@@ -23,7 +23,7 @@ import datetime
 import time
 from nwmanager import *
 
-__version__ = '0.0.1'
+__version__ = '0.0.3'
 AVATAR_CACHE_FOLDER = os.path.join(os.path.expanduser("~"),'.khweeteur','cache')
 CACHE_PATH = os.path.join(os.path.expanduser("~"),'.khweeteur','tweets.cache')
 
@@ -54,8 +54,15 @@ class KhweeteurWorker(QThread):
         self.settings = QSettings()
 
     def run(self):
+        self.testCacheFolders()
         self.refresh()
 
+    def testCacheFolders(self):
+        if not os.path.isdir(os.path.dirname(CACHE_PATH)):
+            os.mkdir(os.path.dirname(CACHE_PATH))
+        if not os.path.isdir(AVATAR_CACHE_FOLDER):
+            os.mkdir(AVATAR_CACHE_FOLDER)
+        
     def downloadProfileImage(self,status):
         if type(status)!=twitter.DirectMessage:
             cache = os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(status.user.profile_image_url))
@@ -155,10 +162,10 @@ class KhweetsModel(QAbstractListModel):
             pkl_file = open(CACHE_PATH, 'rb')
             items = pickle.load(pkl_file)
             self.setData(items)
-        except StandardError,e:
-            print e
-        finally:
             pkl_file.close()
+        except StandardError,e:
+            print e            
+        finally:
             #14 Day limitations
             current_dt = time.mktime((datetime.datetime.now() - datetime.timedelta(days=14)).timetuple())
             for index, item in enumerate(self._items):
